@@ -10,11 +10,12 @@ import argparse
 import shlex
 import sys
 from wpwatcher import VERSION, AUTHORS, GIT_URL, log, init_log
-from wpwatcher.utils import parse_timedelta, results_summary
+from wpwatcher.utils import parse_timedelta
 from wpwatcher.config import WPWatcherConfig
 from wpwatcher.core import WPWatcher
 from wpwatcher.db import WPWatcherDataBase
 from wpwatcher.daemon import WPWatcherDaemon
+from wpwatcher.syslogout import WPSyslogOutput
 
 class WPWatcherCLI():
     """Main program class"""
@@ -36,6 +37,9 @@ class WPWatcherCLI():
         if args.wprs!=False: self.wprs(args.wprs, args.daemon)
         # Read config
         configuration=self.build_config_cli(args)
+        # Launch syslog test
+        if args.syslog_test:
+            self.syslog_test(configuration)
         # If daemon lopping
         if configuration['daemon']: 
             # Run 4 ever
@@ -51,7 +55,7 @@ class WPWatcherCLI():
     def wprs(filepath=None, daemon=False):
         """Generate JSON file database summary"""
         db=WPWatcherDataBase(filepath, daemon=daemon)
-        sys.stdout.buffer.write(results_summary(db._data).encode('utf8'))
+        sys.stdout.buffer.write(WPWatcher.results_summary(db._data).encode('utf8'))
         sys.stdout.flush()
         exit(0)
 
@@ -69,6 +73,13 @@ class WPWatcherCLI():
         sys.stdout.flush()
         exit(0)
 
+    @staticmethod
+    def syslog_test(conf):
+        """Launch the emit_test_messages() method"""
+        syslog = WPSyslogOutput(conf)
+        syslog.emit_test_messages()
+        exit(0)
+
     @staticmethod
     def parse_args():
         """Parse CLI arguments, arguments can overwrite config file values"""
@@ -107,6 +118,8 @@ class WPWatcherCLI():
         parser.add_argument('--quiet', '-q', help="Print only errors and WPScan ALERTS", action='store_true')
         parser.add_argument('--version', '-V', help="Print WPWatcher version", action='store_true')
         parser.add_argument('--wprs', metavar="Path", help="Print database summary table (wp_reports in config) summary. Leave path blank to find default file. Can be used with --daemon to print default daemon databse.", nargs='?', default=False)
+        parser.add_argument('--syslog_test', help="Sends syslog testing packets of all possible sorts to the configured syslog server.", action='store_true')
+
 
         args = parser.parse_args()
         return(args)
