@@ -145,7 +145,6 @@ class WPWatcherNotification():
             # No report notice
             log.info("Not sending WPWatcher %s email report for site %s because already sent in the last %s."%(wp_report['status'], wp_report['site'], self.resend_emails_after))
             should=False
-
         
         return should
 
@@ -172,7 +171,7 @@ class WPWatcherNotification():
         # Handle send mail error
         except (smtplib.SMTPException, ConnectionRefusedError, TimeoutError) as err:
             log.error("Unable to send mail report for site " + wp_site['url'] + "\n" + traceback.format_exc())
-            wp_report['errors'].append("Unable to send mail report" + "\n" + traceback.format_exc())
+            wp_report['error']+="Unable to send mail report for site " + wp_site['url'] + "\n" + traceback.format_exc()
             raise RuntimeError("Unable to send mail report") from err
 
     @staticmethod
@@ -182,8 +181,6 @@ class WPWatcherNotification():
         message="<p>WordPress security scan report for site: %s<br />\n" % (wp_report['site'])
         message+="Scan datetime: %s<br />\n<p>" % (wp_report['datetime'])
         
-        # Adjust wpscan_out_parse 'error' key in results 
-        wp_report['error']='\n'.join(wp_report['errors'])
         message+=format_results(wp_report, format='html')
             
         message += "<br />\n<br />\n--"
