@@ -4,6 +4,8 @@ Automating WPscan to scan and report vulnerable Wordpress sites
 
 DISCLAIMER - USE AT YOUR OWN RISK.
 """
+import socket
+import logging
 import threading
 import re
 import os
@@ -11,17 +13,20 @@ import time
 import signal
 import traceback
 from datetime import timedelta, datetime
-from wpwatcher import log
+from wpwatcher import VERSION, log
+import wpwatcher
 from wpwatcher.utils import get_valid_filename, safe_log_wpscan_args, oneline, timeout
 from wpscan_out_parse.parser import parse_results_from_string, WPScanJsonParser
+from wpscan_out_parse.formatter import format_results
 from wpwatcher.notification import WPWatcherNotification
 from wpwatcher.wpscan import WPScanWrapper
+from wpwatcher.syslogout import WPSyslogOutput
 
 # Wait when API limit reached
 API_WAIT_SLEEP=timedelta(hours=24)
 
 # Send kill signal after X seconds when cancelling
-INTERRUPT_TIMEOUT=10
+INTERRUPT_TIMEOUT=3
 
 # Date format used everywhere
 DATE_FORMAT='%Y-%m-%dT%H-%M-%S'
@@ -63,6 +68,39 @@ class WPWatcherScanner():
             os.makedirs(os.path.join(self.wpscan_output_folder,'warning/'), exist_ok=True)
             os.makedirs(os.path.join(self.wpscan_output_folder,'info/'), exist_ok=True)
 
+        self.syslog=None
+        if conf['syslog_server']:
+            self.syslog = WPSyslogOutput(conf)
+
+    @staticmethod
+    def get_cef_syslog_message(wp_report):
+        from cefevent import CEFEvent
+
+        c = CEFEvent()  
+        c.set_field('name', 'WPWatcher scan report') 
+        c.set_field('deviceVendor', 'Github') 
+        c.set_field('deviceProduct', 'WPWatcher') 
+        c.set_field('deviceVersion', VERSION) 
+        c.set_field('severity', ( 9 if wp_report['status'] == 'ALERT'
+            else 7 if wp_report['status'] == 'WARNING' 
+            else 5 if wp_report['status'] == 'ERROR'
+            else 3 ))
+        c.set_field('message', wp_report['summary']['line'] )   
+        c.set_field("sourceHostName", wp_report['site'])
+        c.set_field("deviceCustomString1", "\n\n".join(wp_report['alerts'])[:1023])
+        c.set_field("deviceCustomString1Label", "alerts")
+        c.set_field("deviceCustomString2", "\n\n".join(wp_report['warnings'])[:1023])
+        c.set_field("deviceCustomString2Label", "warnings")
+        c.set_field("deviceCustomString3", "\n\n".join(wp_report['infos'])[:1023])
+        c.set_field("deviceCustomString3Label", "infos")
+        c.set_field("deviceCustomString4", "\n\n".join(wp_report['fixed'][:1023]))
+        c.set_field("deviceCustomString4Label", "fixed")
+        c.set_field("deviceCustomString5", wp_report['error'])
+        c.set_field("deviceCustomString5Label", "error")
+
+        return c.build_cef() 
+
+
     def check_fail_fast(self):
         '''Fail fast, triger InterruptedError if fail_fast and not already interrupting.'''
         if self.fail_fast and not self.interrupting: 
@@ -77,11 +115,11 @@ class WPWatcherScanner():
         '''
         self.interrupting=True
         # Send ^C to all WPScan not finished
-        for p in self.wpscan.processes: p.send_signal(signal.SIGINT)
+        for p in self.wpscan.processes: 
+            p.terminate()
         # Wait for all processes to finish , kill after timeout
         try: timeout(INTERRUPT_TIMEOUT, self.wait_all_wpscan_process)
         except TimeoutError:
-            log.error("Interrupt timeout reached, killing WPScan processes")
             for p in self.wpscan.processes: p.kill()
         # Unlock api wait
         self.api_wait.set()
@@ -90,7 +128,7 @@ class WPWatcherScanner():
         '''Wait all WPScan processes. To be called with timeout() function
         '''
         while len(self.wpscan.processes)>0:
-            time.sleep(0.05)
+            time.sleep(0.5)
         
     # Scan process
 
@@ -120,7 +158,7 @@ class WPWatcherScanner():
         '''Write WPScan output to configured place with `wpscan_output_folder` or return None
         '''
         # Subfolder
-        folder="%s/"%wp_report['status'].lower() if wp_report['status']!='FIXED' else 'info/'
+        folder="%s/"%wp_report['status'].lower()
         # Write wpscan output 
         wpscan_results_file=None
         if self.wpscan_output_folder :
@@ -153,16 +191,15 @@ class WPWatcherScanner():
     def log_report_results(self, wp_report):
         '''Print WPScan findings'''
         for info in wp_report['infos']: log.info(oneline("** WPScan INFO %s ** %s" % (wp_report['site'], info )))
-        for fix in wp_report['fixed']: log.info(oneline("** FIXED %s ** %s" % (wp_report['site'], fix )))
+        for fix in wp_report['fixed']: log.info(oneline("** FIXED Issue %s ** %s" % (wp_report['site'], fix )))
         for warning in wp_report['warnings']: log.warning(oneline("** WPScan WARNING %s ** %s" % (wp_report['site'], warning )))
         for alert in wp_report['alerts']: log.critical(oneline("** WPScan ALERT %s ** %s" % (wp_report['site'], alert )))
 
     def fill_report_status(self, wp_report):
         '''Fill Report status according to the number of items n alerts, watnings, infos, errors and fixed'''
-        if len(wp_report['errors'])>0:wp_report['status']="ERROR"
+        if len(wp_report['error'])>0:wp_report['status']="ERROR"
         elif len(wp_report['warnings'])>0 and len(wp_report['alerts']) == 0: wp_report['status']='WARNING'
         elif len(wp_report['alerts'])>0: wp_report['status']='ALERT'
-        elif len(wp_report['fixed'])>0: wp_report['status']='FIXED'
         else: wp_report['status']='INFO'
 
     def handle_wpscan_err_api_wait(self,wp_site, wp_report):
@@ -196,7 +233,7 @@ class WPWatcherScanner():
         else:
             err_str="Could not parse the URL to follow in WPScan output after words 'The URL supplied redirects to'"
             log.error(err_str)
-            wp_report['errors'].append(err_str)
+            wp_report['error']+=err_str
             return ((wp_report, False))
 
     def handle_wpscan_err(self, wp_site, wp_report):
@@ -223,26 +260,25 @@ class WPWatcherScanner():
         # Launch WPScan 
         (wpscan_exit_code, wp_report["wpscan_output"]) = self.wpscan.wpscan(*wpscan_arguments)
 
+        log.debug("Parsing WPScan output")
+        try:
+            # Call parse_results_from_string from wpscan_out_parse module 
+            results = parse_results_from_string(wp_report['wpscan_output'] ,
+                self.false_positive_strings + wp_site['false_positive_strings'] + ['No WPVulnDB API Token given'] )
+
+            wp_report['infos'], wp_report['warnings'] , wp_report['alerts'], wp_report['summary'] = results['infos'], results['warnings'], results['alerts'], results['summary']
+            
+            if results['error']:
+                wp_report['error']+=results['error']
+
+        except Exception as err:
+            err_str="Could not parse WPScan output for site %s\n%s"%(wp_site['url'],traceback.format_exc())
+            log.error(err_str)
+            raise RuntimeError(err_str) from err
+
         # Exit code 0: all ok. Exit code 5: Vulnerable. Other exit code are considered as errors
         if wpscan_exit_code in [0,5]:
-            # Call parse_result from parser.py 
-            log.debug("Parsing WPScan output")
-            try:
-                results = parse_results_from_string(wp_report['wpscan_output'] ,
-                    self.false_positive_strings + wp_site['false_positive_strings'] + ['No WPVulnDB API Token given'] )
-
-                wp_report['infos'], wp_report['warnings'] , wp_report['alerts'], wp_report['summary'] = results['infos'], results['warnings'], results['alerts'], results['summary']
-                if results['error']:
-                    wp_report['errors'].append(results['error'])
-
-                # Should not be useful
-                # wp_report['errors'] = [] # clear errors if any
-            except Exception as err:
-                err_str="Could not parse WPScan output for site %s\n%s"%(wp_site['url'],traceback.format_exc())
-                log.error(err_str)
-                raise RuntimeError(err_str) from err
-            else:
-                return wp_report
+            return wp_report
         
         # Quick return if interrupting and/or if user cacelled scans
         if self.interrupting or wpscan_exit_code in [2, -2, -9]:
@@ -264,7 +300,7 @@ class WPWatcherScanner():
             if wp_report_new: wp_report.update(wp_report_new)
             else : return None
         except TimeoutError:
-            wp_report['errors'].append("Timeout scanning site after %s seconds.\nSetup scan_timeout in config file to allow more time"%self.scan_timeout.total_seconds())
+            wp_report['error']+="Timeout scanning site after %s seconds.\nSetup scan_timeout in config file to allow more time"%self.scan_timeout.total_seconds()
             log.error("Timeout scanning site %s after %s seconds. Setup scan_timeout in config file to allow more time"%(wp_site['url'], self.scan_timeout.total_seconds()))
             # Kill process
             for p in self.wpscan.processes:
@@ -285,7 +321,7 @@ class WPWatcherScanner():
             "status":None,
             "datetime": datetime.now().strftime(DATE_FORMAT),
             "last_email":None,
-            "errors":[],
+            "error":'',
             "infos":[],
             "warnings":[],
             "alerts":[],
@@ -301,7 +337,8 @@ class WPWatcherScanner():
         # Launch WPScan
         try:
             # If report is None, return None right away
-            if not self.wpscan_site(wp_site, wp_report): return None
+            if not self.wpscan_site(wp_site, wp_report): 
+                return None
 
         except RuntimeError as err:
             # Try to handle error and return, will recall scan_site()
@@ -313,7 +350,7 @@ class WPWatcherScanner():
             elif not self.interrupting: 
                 log.error("Could not scan site %s"%wp_site['url'])
                 log.debug(traceback.format_exc())
-                wp_report['errors'].append(str(err))
+                wp_report['error']+=str(err)
                 # Fail fast
                 self.check_fail_fast()
 
@@ -344,12 +381,25 @@ class WPWatcherScanner():
         except RuntimeError: 
             # Fail fast
             self.check_fail_fast()
-        
-        # Save scanned site
-        self.scanned_sites.append(wp_site['url'])
+
+        self.fill_report_status(wp_report)
 
         # Discard wpscan_output from report
         if 'wpscan_output' in wp_report: 
             del wp_report['wpscan_output']
 
+        # Send syslog if self.syslog is not None
+        if self.syslog:
+            try:
+                self.syslog.emit_messages(wp_report)
+            except Exception as err:
+                log.error("Unable to send the syslog messages for site "+wp_site['url']+"\n"+traceback.format_exc())
+                wp_report['error']+="Unable to send all syslog messages for site "+wp_site['url']+"\n"+traceback.format_exc()
+                self.check_fail_fast()
+
+        self.fill_report_status(wp_report)
+
+        # Save scanned site
+        self.scanned_sites.append(wp_site['url'])
+
         return(wp_report)
